@@ -38,7 +38,7 @@ NULL
 #' isNMFfit(res)
 #' 
 #' # multiple runs - keeping single fit
-#' resm <- nmf(V, 3, nrun=3, maxIter=3L)
+#' resm <- nmf(V, 3, nrun=2, maxIter=3L)
 #' isNMFfit(resm)
 #' 
 #' # with a list of results
@@ -455,7 +455,7 @@ setGeneric('getRNG1', package='rngtools')
 #' @examples
 #' # For multiple NMF runs, the RNG settings used for the first run is also stored
 #' V <- rmatrix(20,10)
-#' res <- nmf(V, 3, nrun=4)
+#' res <- nmf(V, 3, nrun=3)
 #' # RNG used for the best fit
 #' getRNG(res)
 #' # RNG used for the first of all fits
@@ -535,21 +535,21 @@ setMethod('deviance', signature(object='NMFfitX'),
 #' @examples
 #' 
 #' # generate a synthetic dataset with known classes
-#' n <- 20; counts <- c(5, 2, 3);
-#' V <- syntheticNMF(n, counts)
+#' n <- 15; counts <- c(5, 2, 3);
+#' V <- syntheticNMF(n, counts, factors = TRUE)
 #' 
 #' # get the class factor
 #' groups <- V$pData$Group
 #' 
 #' # perform multiple runs of one algorithm, keeping only the best fit (default)
 #' #i.e.: the implicit nmf options are .options=list(keep.all=FALSE) or .options='-k'
-#' res <- nmf(V, 3, nrun=3) 
+#' res <- nmf(V[[1]], 3, nrun=2) 
 #' res
 #' 
 #' # compute summary measures
 #' summary(res)
 #' # get more info
-#' summary(res, target=V, class=groups)
+#' summary(res, target=V[[1]], class=groups)
 #' 
 #' # show computational time
 #' runtime.all(res)
@@ -685,19 +685,19 @@ setMethod('nmf.equal', signature(x='NMFfitX1', y='NMFfitX1'),
 #' @examples
 #' 
 #' # generate a synthetic dataset with known classes
-#' n <- 20; counts <- c(5, 2, 3);
-#' V <- syntheticNMF(n, counts)
+#' n <- 15; counts <- c(5, 2, 3);
+#' V <- syntheticNMF(n, counts, factors = TRUE)
 #' 
 #' # get the class factor
 #' groups <- V$pData$Group
 #' 
 #' # perform multiple runs of one algorithm, keeping all the fits
-#' res <- nmf(V, 3, nrun=3, .options='k') # .options=list(keep.all=TRUE) also works
+#' res <- nmf(V[[1]], 3, nrun=2, .options='k') # .options=list(keep.all=TRUE) also works
 #' res
 #'  
 #' summary(res)
 #' # get more info
-#' summary(res, target=V, class=groups)
+#' summary(res, target=V[[1]], class=groups)
 #' 
 #' # compute/show computational times
 #' runtime.all(res)
@@ -1315,18 +1315,24 @@ setMethod('entropy', signature(x='NMFfitXn', y='ANY'),
 	}
 )
 
-###% Utility function to aggregate numerical quality measures from \code{NMFfitXn} objects.
-###% 
-###% Given a numerical vector, this function computes an aggregated value using one of the following methods:
-###% - mean: the mean of the measures
-###% - best: the best measure according to the specified sorting order (decreasing or not)
-###%  
-aggregate.measure <- function(measure, method=c('best', 'mean'), decreasing=FALSE){
+#' Utility function to aggregate numerical quality measures from \code{NMFfitXn} objects.
+#' 
+#' Given a numerical vector, this function computes an aggregated value using one of the following methods:
+#' best or mean
+#' 
+#' @param x  a numerical vector
+#' @param method the method to aggregate values. This argument can take two values :
+#' - mean: the mean of the measures
+#' - best: the best measure according to the specified sorting order (decreasing or not)
+#' @param decreasing  logical that specified the sorting order 
+#' @param ... extra arguments to allow extension
+#' 
+aggregate.measure <- function(x, method=c('best', 'mean'), decreasing=FALSE,...){
 	# aggregate the results
 	method <- match.arg(method)
 	res <- switch(method
-			, mean = mean(measure)
-			, best = if( decreasing ) max(measure) else min(measure)
+			, mean = mean(x)
+			, best = if( decreasing ) max(x) else min(x)
 	)
 	
 	# set the name to 
